@@ -201,8 +201,10 @@ class BackTestEngine:
                 if _startKlines:
                     _price = _startKlines[0].openingPrice
                 else:
-                    raise Exception("kline from " + str(_startTimeStamp) + " not found")
-
+                    _startKlines = self.__dataSource.queryLatestKline(_tc, _symbol, KlinePeriod.MIN_1, endTimeMills=_startTimeStamp, limit=1)
+                    if not _startKlines:
+                        raise Exception("kline to " + str(_startTimeStamp) + " not found")
+                    _price = _startKlines[0].closingPrice
                 _startTotalAmount = _startTotalAmount + (_position.remainAmount + _position.remainHolding * _price)
 
             try:
