@@ -79,10 +79,10 @@ class BackTestResult:
             if i == 0:
                 v['drawDown'] = decimal.Decimal('0')
             else:
-                _max_profit = max(_amountChangeList[0:i + 1], key=lambda x: x['profitRate'])
-                v['drawDown'] = v['profitRate'] - _max_profit
-        _maxDrawDown = max(_amountChangeList, key=lambda x: x['drawDown'])
-        return _maxDrawDown
+                _max_dict = max(_amountChangeList[0:i + 1], key=lambda x: x['profitRate'])
+                v['drawDown'] = v['profitRate'] - _max_dict['profitRate']
+        _minDict = min(_amountChangeList, key=lambda x: x['drawDown'])
+        return _minDict['drawDown']
 
 
 class Profit:
